#[non_exhaustive]pub struct UpdateNamedQueryInput {
pub named_query_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub query_string: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.named_query_id: Option<String>The unique identifier (UUID) of the query.
name: Option<String>The name of the query.
description: Option<String>The query description.
query_string: Option<String>The contents of the query with all query statements.
Implementations
Sourceimpl UpdateNamedQueryInput
impl UpdateNamedQueryInput
Sourcepub fn named_query_id(&self) -> Option<&str>
pub fn named_query_id(&self) -> Option<&str>
The unique identifier (UUID) of the query.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The query description.
Sourcepub fn query_string(&self) -> Option<&str>
pub fn query_string(&self) -> Option<&str>
The contents of the query with all query statements.
Sourceimpl UpdateNamedQueryInput
impl UpdateNamedQueryInput
Sourcepub fn builder() -> UpdateNamedQueryInputBuilder
pub fn builder() -> UpdateNamedQueryInputBuilder
Creates a new builder-style object to manufacture UpdateNamedQueryInput.